import { XeroClientConfiguration, BaseAPIClient } from './internals/BaseAPIClient';
import { IOAuth1HttpClient, AccessToken } from './internals/OAuth1HttpClient';
import { AccountsResponse, BankTransactionsResponse, InvoicesResponse, CreditNotesResponse, AllocationsResponse, ContactGroupsResponse, CurrenciesResponse, EmployeesResponse, ContactsResponse, ReportsResponse, AttachmentsResponse, OrganisationResponse, UsersResponse, BrandingThemesResponse, BankTransfersResponse, TrackingCategoriesResponse, TaxRatesResponse, ExpenseClaimsResponse, ItemsResponse, InvoiceRemindersResponse, JournalsResponse, PaymentsResponse, PrepaymentsResponse, OverpaymentsResponse, LinkedTransactionsResponse, ReceiptsResponse, ManualJournalsResponse, RepeatingInvoicesResponse, PurchaseOrdersResponse } from './AccountingAPI-responses';
import { BankTransaction, BankTransfer, ContactGroup, Contact, CreditNote, Allocation, Currency, Employee, ExpenseClaim, Invoice, Item, LinkedTransaction, Payment, TaxRate, TrackingCategory, TrackingOption, Receipt, ManualJournal, PurchaseOrder } from './AccountingAPI-models';
export interface QueryArgs {
    where?: string;
    order?: string;
}
export interface PagingArgs {
    page?: number;
}
export interface UnitDecimalPlacesArgs {
    unitdp?: number;
}
export interface HeaderArgs {
    'If-Modified-Since'?: string;
}
/** @private */
export interface AttachmentsEndpoint {
    get(args: {
        entityId: string;
    }): Promise<AttachmentsResponse>;
    downloadAttachment(args: {
        entityId: string;
        mimeType: string;
        fileName: string;
        pathToSave: string;
    }): Promise<void>;
    uploadAttachment(args: {
        entityId: string;
        mimeType: string;
        fileName: string;
        pathToUpload: string;
        includeOnline?: boolean;
    }): Promise<AttachmentsResponse>;
}
export declare class AccountingAPIClient extends BaseAPIClient {
    constructor(options: XeroClientConfiguration, authState?: AccessToken, _oAuth1HttpClient?: IOAuth1HttpClient);
    private generateAttachmentsEndpoint(path);
    private generateHeader(args);
    accounts: {
        get: (args?: {
            AccountID?: string;
        } & QueryArgs & HeaderArgs) => Promise<AccountsResponse>;
        create: (account: any) => Promise<AccountsResponse>;
        update: (account: any, args?: {
            AccountID?: string;
        }) => Promise<AccountsResponse>;
        delete: (args: {
            AccountID: string;
        }) => Promise<AccountsResponse>;
        attachments: AttachmentsEndpoint;
    };
    bankTransactions: {
        get: (args?: {
            BankTransactionID?: string;
        } & QueryArgs & PagingArgs & UnitDecimalPlacesArgs & HeaderArgs) => Promise<BankTransactionsResponse>;
        create: (bankTransaction: BankTransaction | {
            BankTransactions: BankTransaction[];
        }, args?: {
            summarizeErrors?: boolean;
        } & UnitDecimalPlacesArgs) => Promise<BankTransactionsResponse>;
        update: (bankTransaction: BankTransaction | {
            BankTransactions: BankTransaction[];
        }, args?: {
            summarizeErrors?: boolean;
        } & UnitDecimalPlacesArgs) => Promise<BankTransactionsResponse>;
        attachments: AttachmentsEndpoint;
    };
    bankTransfers: {
        get: (args?: {
            BankTransferID?: string;
        } & HeaderArgs & QueryArgs) => Promise<BankTransfersResponse>;
        create: (bankTransfers: BankTransfer | {
            BankTransfers: BankTransfer[];
        }, args?: {
            summarizeErrors: boolean;
        }) => Promise<BankTransfersResponse>;
        attachments: AttachmentsEndpoint;
    };
    brandingThemes: {
        get: (args?: {
            BrandingThemeID?: string;
        }) => Promise<BrandingThemesResponse>;
    };
    contactGroups: {
        get: (args?: {
            ContactGroupID?: string;
        } & QueryArgs) => Promise<ContactGroupsResponse>;
        create: (contactGroups: ContactGroup | {
            ContactGroups: ContactGroup[];
        }, args?: {
            summarizeErrors?: boolean;
        }) => Promise<ContactGroupsResponse>;
        update: (contactGroups: ContactGroup | {
            ContactGroups: ContactGroup[];
        }, args?: {
            ContactGroupID: string;
            summarizeErrors?: boolean;
        }) => Promise<ContactGroupsResponse>;
        contacts: {
            delete: (args: {
                ContactGroupID: string;
                ContactID?: string;
            }) => Promise<ContactsResponse>;
            create: (contact: Contact, args: {
                ContactGroupID: string;
            }) => Promise<ContactsResponse>;
        };
    };
    contacts: {
        get: (args?: {
            ContactID?: string;
            includeArchived?: boolean;
            IDs?: string;
        } & HeaderArgs & PagingArgs & QueryArgs) => Promise<ContactsResponse>;
        create: (body: Contact | {
            Contacts: Contact[];
        }, args?: {
            summarizeErrors: boolean;
        }) => Promise<ContactsResponse>;
        update: (body?: Contact | {
            Contacts: Contact[];
        }, args?: {
            ContactID: string;
            summarizeErrors: boolean;
        }) => Promise<ContactsResponse>;
        CISsettings: {
            get: (args?: {
                ContactID: string;
            }) => Promise<string>;
        };
        attachments: AttachmentsEndpoint;
    };
    creditNotes: {
        get: (args?: {
            CreditNoteID?: string;
        } & QueryArgs & PagingArgs & UnitDecimalPlacesArgs & HeaderArgs) => Promise<CreditNotesResponse>;
        savePDF: (args?: {
            CreditNoteID: string;
            savePath: string;
        }) => Promise<void>;
        create: (creditNote: CreditNote | {
            CreditNotes: CreditNote[];
        }, args?: {
            summarizeErrors?: boolean;
        } & UnitDecimalPlacesArgs) => Promise<CreditNotesResponse>;
        update: (creditNote: CreditNote | {
            CreditNotes: CreditNote[];
        }, args?: {
            summarizeErrors?: boolean;
        } & UnitDecimalPlacesArgs) => Promise<CreditNotesResponse>;
        allocations: {
            create: (allocation: Allocation, args?: {
                CreditNoteID?: string;
            }) => Promise<AllocationsResponse>;
        };
        attachments: AttachmentsEndpoint;
    };
    currencies: {
        get: (args?: QueryArgs) => Promise<CurrenciesResponse>;
        create: (currency: Currency) => Promise<CurrenciesResponse>;
    };
    employees: {
        get: (args?: {
            EmployeeID?: string;
        } & QueryArgs & HeaderArgs) => Promise<EmployeesResponse>;
        create: (employees: Employee | {
            Employees: Employee[];
        }) => Promise<EmployeesResponse>;
        update: (employees: Employee | {
            Employees: Employee[];
        }) => Promise<EmployeesResponse>;
    };
    expenseClaims: {
        get: (args?: {
            ExpenseClaimID?: string;
        } & QueryArgs & HeaderArgs) => Promise<ExpenseClaimsResponse>;
        create: (expenseClaims: ExpenseClaim | {
            ExpenseClaims: ExpenseClaim[];
        }, args?: {
            summarizeErrors?: boolean;
        }) => Promise<ExpenseClaimsResponse>;
        update: (expenseClaims: ExpenseClaim | {
            ExpenseClaims: ExpenseClaim[];
        }, args?: {
            ExpenseClaimID?: string;
            summarizeErrors?: boolean;
        }) => Promise<ExpenseClaimsResponse>;
    };
    invoiceReminders: {
        get: () => Promise<InvoiceRemindersResponse>;
    };
    invoices: {
        get: (args?: {
            InvoiceID?: string;
            InvoiceNumber?: string;
            createdByMyApp?: boolean;
        } & HeaderArgs & PagingArgs & UnitDecimalPlacesArgs & QueryArgs) => Promise<InvoicesResponse>;
        savePDF: (args?: {
            InvoiceID: string;
            InvoiceNumber?: string;
            savePath: string;
        }) => Promise<void>;
        create: (invoice: Invoice | {
            Invoices: Invoice[];
        }, args?: {
            summarizeErrors?: boolean;
        } & UnitDecimalPlacesArgs) => Promise<InvoicesResponse>;
        update: (invoices: Invoice | {
            Invoices: Invoice[];
        }, args?: {
            InvoiceID?: string;
            InvoiceNumber?: string;
            where?: string;
            summarizeErrors?: boolean;
        } & UnitDecimalPlacesArgs) => Promise<InvoicesResponse>;
        onlineInvoice: {
            get: (args?: {
                InvoiceID: string;
            }) => Promise<string>;
        };
        attachments: AttachmentsEndpoint;
    };
    repeatingInvoices: {
        get: (args?: {
            RepeatingInvoiceID?: string;
        } & QueryArgs) => Promise<RepeatingInvoicesResponse>;
        attachments: AttachmentsEndpoint;
    };
    items: {
        get: (args?: {
            ItemID?: string;
            Code?: string;
        } & QueryArgs & HeaderArgs) => Promise<ItemsResponse>;
        create: (items: Item | {
            Items: Item[];
        }, args?: {
            summarizeErrors?: boolean;
        }) => Promise<ItemsResponse>;
        update: (items: Item | {
            Items: Item[];
        }, args?: {
            ItemID?: string;
            summarizeErrors?: boolean;
        }) => Promise<ItemsResponse>;
        delete: (args: {
            ItemID: string;
        }) => Promise<ItemsResponse>;
    };
    journals: {
        get: (args?: {
            Recordfilter?: string;
            offset?: string;
            paymentsOnly?: boolean;
        } & HeaderArgs) => Promise<JournalsResponse>;
    };
    linkedTransactions: {
        get: (args?: {
            LinkedTransactionID?: string;
        } & QueryArgs & UnitDecimalPlacesArgs & HeaderArgs) => Promise<LinkedTransactionsResponse>;
        create: (linkedTransaction: LinkedTransaction | {
            LinkedTransactions: LinkedTransaction[];
        }, args?: {
            summarizeErrors?: boolean;
        } & UnitDecimalPlacesArgs) => Promise<LinkedTransactionsResponse>;
        update: (linkedTransaction: LinkedTransaction | {
            LinkedTransactions: LinkedTransaction[];
        }, args?: {
            LinkedTransactionID?: string;
            summarizeErrors?: boolean;
        } & UnitDecimalPlacesArgs) => Promise<LinkedTransactionsResponse>;
        delete: (args?: {
            LinkedTransactionID?: string;
        }) => Promise<void>;
    };
    manualJournals: {
        get: (args?: {
            ManualJournalID?: string;
        } & QueryArgs & PagingArgs & HeaderArgs) => Promise<ManualJournalsResponse>;
        create: (manualJournals?: ManualJournal | {
            ManualJournals: ManualJournal[];
        }, args?: {
            summarizeErrors?: boolean;
        }) => Promise<ManualJournalsResponse>;
        update: (manualJournals?: ManualJournal | {
            ManualJournals: ManualJournal[];
        }, args?: {
            ManualJournalID?: string;
            summarizeErrors?: boolean;
        }) => Promise<ManualJournalsResponse>;
        attachments: AttachmentsEndpoint;
    };
    organisations: {
        get: () => Promise<OrganisationResponse>;
        CISSettings: {
            get: (args: {
                OrganisationID: string;
                where?: string;
            }) => Promise<OrganisationResponse>;
        };
    };
    overpayments: {
        get: (args?: {
            OverpaymentID?: string;
        } & QueryArgs & PagingArgs & UnitDecimalPlacesArgs & HeaderArgs) => Promise<OverpaymentsResponse>;
        allocations: {
            create: (body: Allocation[], args: {
                OverpaymentID: string;
            }) => Promise<OverpaymentsResponse>;
        };
    };
    payments: {
        get: (args?: {
            PaymentID: string;
        } & QueryArgs & HeaderArgs) => Promise<PaymentsResponse>;
        create: (payments: Payment | {
            Payments: Payment[];
        }, args?: {
            summarizeErrors?: boolean;
        }) => Promise<PaymentsResponse>;
        update: (payments: Payment | {
            Payments: Payment[];
        }, args?: {
            PaymentID: string;
            summarizeErrors?: boolean;
        }) => Promise<PaymentsResponse>;
    };
    prepayments: {
        get: (args?: {
            PrepaymentID: string;
        } & QueryArgs & PagingArgs & UnitDecimalPlacesArgs & HeaderArgs) => Promise<PrepaymentsResponse>;
        allocations: {
            create: (allocations: Allocation | {
                Allocations: Allocation[];
            }, args: {
                PrepaymentID: string;
            }) => Promise<PrepaymentsResponse>;
        };
        attachments: AttachmentsEndpoint;
    };
    purchaseOrders: {
        get: (args?: {
            PurchaseOrderID?: string;
            PurchasOrderNumber?: string;
            Status?: string;
            DateFrom?: string;
            DateTo?: string;
        } & QueryArgs & HeaderArgs) => Promise<PurchaseOrdersResponse>;
        create: (purchaseOrders?: PurchaseOrder | {
            PurchaseOrders: PurchaseOrder[];
        }, args?: {
            summarizeErrors: boolean;
        }) => Promise<PurchaseOrdersResponse>;
        update: (purchaseOrders?: PurchaseOrder | {
            PurchaseOrders: PurchaseOrder[];
        }, args?: {
            PurchaseOrderID?: string;
            summarizeErrors?: boolean;
        }) => Promise<PurchaseOrdersResponse>;
    };
    receipts: {
        get: (args?: {
            ReceiptID?: string;
        } & QueryArgs & UnitDecimalPlacesArgs & HeaderArgs) => Promise<ReceiptsResponse>;
        create: (receipts?: Receipt | {
            Receipts: Receipt[];
        }, args?: {
            summarizeErrors?: boolean;
        } & UnitDecimalPlacesArgs) => Promise<ReceiptsResponse>;
        update: (receipts?: Receipt | {
            Receipts: Receipt[];
        }, args?: {
            ReceiptID?: string;
            summarizeErrors?: boolean;
        } & UnitDecimalPlacesArgs) => Promise<ReceiptsResponse>;
        attachments: AttachmentsEndpoint;
    };
    reports: {
        get: (args?: {
            ReportID: string;
        }) => Promise<ReportsResponse>;
    };
    taxRates: {
        get: (args?: {
            TaxType?: string;
        } & QueryArgs) => Promise<TaxRatesResponse>;
        create: (body?: TaxRate) => Promise<TaxRatesResponse>;
        update: (body?: TaxRate) => Promise<TaxRatesResponse>;
    };
    trackingCategories: {
        get: (args?: {
            TrackingCategoryID?: string;
            includeArchived?: boolean;
        } & HeaderArgs & QueryArgs) => Promise<TrackingCategoriesResponse>;
        create: (trackingCategory: TrackingCategory | {
            TrackingCategorys: TrackingCategory[];
        }) => Promise<TrackingCategoriesResponse>;
        update: (trackingCategory: TrackingCategory | {
            TrackingCategorys: TrackingCategory[];
        }, args?: {
            TrackingCategoryID: string;
        }) => Promise<TrackingCategoriesResponse>;
        delete: (args: {
            TrackingCategoryID: string;
        }) => Promise<any>;
        trackingOptions: {
            create: (trackingOption: TrackingOption | {
                TrackingOptions: TrackingOption[];
            }, args?: {
                TrackingCategoryID: string;
            }) => Promise<TrackingCategoriesResponse>;
            update: (trackingOption: TrackingOption | {
                TrackingOptions: TrackingOption[];
            }, args?: {
                TrackingCategoryID: string;
                TrackingOptionID: string;
            }) => Promise<TrackingCategoriesResponse>;
            delete: (args: {
                TrackingCategoryID: string;
                TrackingOptionID: string;
            }) => Promise<any>;
        };
    };
    users: {
        get: (args?: {
            UserID?: string;
        } & HeaderArgs & QueryArgs) => Promise<UsersResponse>;
    };
}
